@@ -16,11 +16,11 @@ class QueryClusterCoachDBScan(QueryClusterCoach):
         :param max_exp_count:
         :return:
         """
-        self.estimators = {
-            i: EstimatorElem(
-                estimator=cluster.DBSCAN(min_samples=i + 2, eps=0.2),
-                class_num=5) for i in range(max_exp_count)
-        }
+        params = [(2, 0.01 + i * 0.01) for i in range(20)] + [(3, 0.01 + i * 0.01) for i in range(20)]
+        for index, param in enumerate(params):
+            self.estimators[index] = EstimatorElem(
+                estimator=cluster.DBSCAN(min_samples=param[0], eps=param[1]), class_num=3
+            )
 
     def search_best_model(self, scores: List[EvaluationScore]):
         """
@@ -30,9 +30,9 @@ class QueryClusterCoachDBScan(QueryClusterCoach):
         best_value = -10000
         best_score = EvaluationScore()
         for score in scores:
-            if score.silhouette > best_value:
+            if score.calinski_harabasz > best_value:
                 best_score = score.copy()
-                best_value = score.silhouette
+                best_value = score.calinski_harabasz
 
         self.model.set_model_score(best_score.copy())
 
