@@ -21,7 +21,7 @@ from pydantic import BaseModel
 
 import numpy
 from sklearn import preprocessing, metrics, cluster
-from nlp_nn.nlp_nn_sent_vector import SentVector
+from nlp_nn.nlp_nn_app.sent_similarity.infer import SentSimilarity
 
 
 class EstimatorElem(BaseModel):
@@ -63,7 +63,7 @@ class QueryClusterModelData(BaseModel):
 class Sentence2Vector(object):
     def __init__(self):
         try:
-            self.sv = SentVector("/".join(os.path.abspath(__file__).split("/")[:-1]) + "/" + "sent2vec.models")
+            self.sv = SentSimilarity("/".join(os.path.abspath(__file__).split("/")[:-1]) + "/" + "sent2vec.models")
         except Exception as exp:
             raise ValueError("Failed to load sentence to vector model %s" % exp)
 
